<?php
namespace Ep\Woo\Plugin\Cart;

use Ep\Woo\Cart\CartEvent;
use Ak\Wp\Plugin\PluginInterface;
use Laminas\EventManager\EventManagerAwareInterface;
use Laminas\EventManager\EventManagerAwareTrait;
use Laminas\EventManager\EventManagerInterface;

/**
 * Class CartEvents
 *
 * @package Ep\Woo\Plugin\Cart
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link http://gitlab.ep.local/ep-framework/woocommerce
 */
final class CartEvents implements
    PluginInterface,
    EventManagerAwareInterface
{
    use EventManagerAwareTrait;

    /**
     * CartEvents constructor.
     *
     * @param EventManagerInterface $events
     */
    public function __construct(EventManagerInterface $events)
    {
        $events->setEventPrototype(new CartEvent());
        $events->setIdentifiers([__CLASS__, get_class($this)]);

        $this->events = $events;
    }

    /**
     * Dodaje akcije i filtere u WordPress.
     */
    public function attach(): void
    {
        add_action('woocommerce_add_to_cart', [$this, 'wc_add_to_cart'], 10, 6);
    }

    public function wc_add_to_cart($cart_item_key, $product_id, $quantity, $variation_id, $variation, $cart_item_data)
    {
        $cart = WC()->cart;
        $events = $this->getEventManager();

        $events->trigger(CartEvent::EVENT_ADD, $cart, [
            'cart_item_key' => $cart_item_key,
            'product_id' => $product_id,
            'quantity' => $quantity,
            'variation_id' => $variation_id,
            'variation' => $variation,
            'cart_item_data' => $cart_item_data,
        ]);
    }
}
