<?php
namespace Ep\Woo\Product;

use WC_Product_Grouped;

/**
 * Class Grouped
 *
 * @package Ep\Woo\Entity\Product
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class Grouped extends WC_Product_Grouped implements ProductInterface
{
    use ProductTrait;

    /** @var array */
    protected $extra_data = [
        'children' => [],
        'price_hidden' => false,
        'purchase_step' => 1,
    ];

    /** @var \WC_Product[] */
    protected $children;

    /**
     * Da li je ovaj proizvod na akciji.
     *
     * @param string $context
     *
     * @return bool
     */
    public function is_on_sale($context = 'view')
    {
        foreach ($this->getChildren() as $child) {
            if ($child->is_on_sale($context)) {
                return true;
            }
        }

        return false;
    }

    /**
     * Da li je ovaj proizvod moguće kupiti iako ga nema na zalihi.
     *
     * @param int $qty_in_cart
     *
     * @return bool
     */
    public function is_on_backorder($qty_in_cart = 0)
    {
        foreach ($this->getChildren() as $child) {
            if ($child->is_on_backorder()) {
                return true;
            }
        }

        return false;
    }

    /**
     * Returns false if the product cannot be bought.
     *
     * @return bool
     */
    public function is_purchasable()
    {
        foreach ($this->getChildren() as $child) {
            if ($child->is_purchasable()) {
                return true;
            }
        }

        return false;
    }

    public function is_price_hidden(): bool
    {
        foreach ($this->children as $child) {
            if ($child instanceof Simple && $child->is_price_hidden()) {
                return true;
            }
        }

        return false;
    }

    /**
     * Vraća proizvode dodane kao djecu ovom grupiranom.
     *
     * @return \WC_Product[]|ProductInterface[]
     */
    public function getChildren(): array
    {
        if (null === $this->children) {
            $childrenIds = $this->get_children();
            $this->children = [];

            foreach ($childrenIds as $childId) {
                if ($product = wc_get_product($childId)) {
                    $this->children[] = $product;
                }
            }
        }

        return $this->children;
    }
}
